==> bluez-qt-5.25.0.zip: bluez-qt-5.25.0/src/imports/declarativeinput.h <==
/*
 * BluezQt - Asynchronous BlueZ wrapper library
 *
 * Copyright (C) 2015 David Rosca <nowrep@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) version 3, or any
 * later version accepted by the membership of KDE e.V. (or its
 * successor approved by the membership of KDE e.V.), which shall
 * act as a proxy defined in Section 6 of version 3 of the license.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DECLARATIVEINPUT_H
#define DECLARATIVEINPUT_H

#include "input.h"

class DeclarativeInput : public QObject
{
    Q_OBJECT
    Q_PROPERTY(BluezQt::Input::ReconnectMode reconnectMode READ reconnectMode NOTIFY reconnectModeChanged)

public:
    explicit DeclarativeInput(BluezQt::InputPtr input, QObject *parent = Q_NULLPTR);

    BluezQt::Input::ReconnectMode reconnectMode() const;

Q_SIGNALS:
    void reconnectModeChanged(BluezQt::Input::ReconnectMode mode);

private:
    BluezQt::InputPtr m_input;
};

#endif // DECLARATIVEINPUT_H

==> bluez-qt-5.43.0.zip: bluez-qt-5.43.0/src/imports/declarativeinput.h <==
/*
 * BluezQt - Asynchronous BlueZ wrapper library
 *
 * Copyright (C) 2015 David Rosca <nowrep@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) version 3, or any
 * later version accepted by the membership of KDE e.V. (or its
 * successor approved by the membership of KDE e.V.), which shall
 * act as a proxy defined in Section 6 of version 3 of the license.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DECLARATIVEINPUT_H
#define DECLARATIVEINPUT_H

#include "input.h"

class DeclarativeInput : public QObject
{
    Q_OBJECT
    Q_PROPERTY(BluezQt::Input::ReconnectMode reconnectMode READ reconnectMode NOTIFY reconnectModeChanged)

public:
    explicit DeclarativeInput(BluezQt::InputPtr input, QObject *parent = nullptr);

    BluezQt::Input::ReconnectMode reconnectMode() const;

Q_SIGNALS:
    void reconnectModeChanged(BluezQt::Input::ReconnectMode mode);

private:
    BluezQt::InputPtr m_input;
};

#endif // DECLARATIVEINPUT_H
